@@ -5,6 +5,7 @@ from sli import commands
 from types import ModuleType
 
 from sli.contextManager import ContextManager
+from sli.commands.base import BaseCommand
 
 
 class SkilletLineInterface:
@@ -63,6 +64,10 @@ class SkilletLineInterface:
                     item_attr_obj = getattr(item_obj, item_attr)
                     if isclass(item_attr_obj):
 
+                        # Only load commands that subclass BaseCommand
+                        if item_attr_obj == BaseCommand or not issubclass(item_attr_obj, BaseCommand):
+                            continue
+
                         # Load only SLI command modules that are appropriately written
                         command_string = getattr(item_attr_obj, "sli_command", "")
                         if len(command_string) > 0:
